==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Machine</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fichier ouvert</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Visualiser les activités CIFS/SMB</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configure</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurer</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Merci à:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Ce programme est distribué selon les termes de la General Public License version 2 </translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Rechercher un texte</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texte non trouvé.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Utilisateur %1 a ouvert le partage %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Utilisateur %1 a ouvert le fichier %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Activités CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Message à envoyer</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Message à envoyer à %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Voulez-vous vraiment déconnecter l&apos;utilisateur %1 ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Envoyer un message à tous les utilisateurs</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Envoyer un message à</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Déconnecter l&apos;utilisateur</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Mise à jour disponible</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Une nouvelle version de %1 est disponible</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Vous pouvez la télécharger ici: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configure</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Autoconnexion</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Adresse par défaut du serveur:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Utilisateur par défaut:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Adresse du serveur</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervalle:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Nom de l&apos;utilisateur ( defaut :  username = root)</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Journal des activités SMB/CIFS</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Messages de notification d&apos;état</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notifications et journal</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Limiter le journal:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>jours</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Afficher QtSmbstatus dans la boite à miniatures</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Intervalle, en secondes, entre deux requêtes à smbstatus (intervalle &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Voir les partages cachés (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Voir les partages cachés</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Autoconnexion au démarrage de qtsmbstatus</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Voir les activités dans des info-bulles</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Rechercher automatiquement des mises à jour</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Une nouvelle version est disponible</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;A propos de QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Connexion/Déconnexion</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hôte:</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configure client</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Rechercher</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Machine</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Utilisateur</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Partage &amp;ouvert</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Fichier ouvert</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Suivant</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Rechercher un texte</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configure QtSmbstatus client</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Rechercher une machine</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Rechercher un utilisateur</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Rechercher un partage ouvert</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Rechercher un fichier ouvert</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Rechercher un texte</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Quitter QtSmbstatus</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nnexion</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Visualiser les activités CIFS/SMB</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>A propos de QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visualiser les activités</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Voir/cacher les partages</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Voir/cacher les fichiers</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Enregistrer le journal</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>login</source>
        <translation>login</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Connexion au serveur</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Mauvais login ou mauvais mot de passe !</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Connexion en cours sur %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connecté au serveur</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connexion fermé</translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.2.0.orig.tar.gz: qtsmbstatus-2.2.0/client/tr/qtsmbstatus_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Machine</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fichier ouvert</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Visualiser les activités CIFS/SMB</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configure</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurer</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Merci à:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Ce programme est distribué selon les termes de la General Public License version 2 </translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Rechercher un texte</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texte non trouvé.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Utilisateur %1 a ouvert le partage %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Utilisateur %1 a ouvert le fichier %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Activités CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Message à envoyer</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Message à envoyer à %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Voulez-vous vraiment déconnecter l&apos;utilisateur %1 ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Envoyer un message à tous les utilisateurs</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Envoyer un message à</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Déconnecter l&apos;utilisateur</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Mise à jour disponible</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Une nouvelle version de %1 est disponible</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Vous pouvez la télécharger ici: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configure</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Autoconnexion</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Adresse par défaut du serveur:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Utilisateur par défaut:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Adresse du serveur</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervalle:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Nom de l&apos;utilisateur ( defaut :  username = root)</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Journal des activités SMB/CIFS</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Messages de notification d&apos;état</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notifications et journal</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Limiter le journal:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>jours</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Afficher QtSmbstatus dans la boite à miniatures</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Intervalle, en secondes, entre deux requêtes à smbstatus (intervalle &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Voir les partages cachés (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Voir les partages cachés</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Autoconnexion au démarrage de qtsmbstatus</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Voir les activités dans des info-bulles</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Rechercher automatiquement des mises à jour</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Une nouvelle version est disponible</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;A propos de QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Connexion/Déconnexion</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hôte:</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configure client</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Rechercher</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Machine</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Utilisateur</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Partage &amp;ouvert</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Fichier ouvert</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Suivant</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Rechercher un texte</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>A propos de Qt</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configure QtSmbstatus client</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Rechercher une machine</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Rechercher un utilisateur</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Rechercher un partage ouvert</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Rechercher un fichier ouvert</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Rechercher un texte</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Quitter QtSmbstatus</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nnexion</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Visualiser les activités CIFS/SMB</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>A propos de QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visualiser les activités</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Voir/cacher les partages</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Voir/cacher les fichiers</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Enregistrer le journal</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>login</source>
        <translation>login</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Connexion au serveur</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Mauvais login ou mauvais mot de passe !</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Connexion en cours sur %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connecté au serveur</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connexion fermé</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation>Le certificat du serveur ne contient pas des données valides ou bien le certificat a expiré !</translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation>L&apos;authenticité de l&apos;hôte &apos;%1&apos; ne peut pas être établie.</translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation>Êtes-vous sûr de vouloir continuer la connexion ?</translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation>Empreinte SHA1: %1.</translation>
    </message>
</context>
</TS>
